The Stingray Modelling Interface
********************************

Stingray provides a custom-built fitting interface, built on top 
of `scipy <https://scipy.org/#>`_ and `emcee <http://dfm.io/emcee/current/>`_ as well as a set of general functions 
and classes that allow the user to perform standard model fitting tasks 
on Fourier products, but also enable users to implement their own models 
and classes based on this framework. 

Below, we show on some examples how this interface can be used.

.. toctree::
   :maxdepth: 2

   notebooks/Modeling/ModelingExamples.ipynb

